@@ -23,28 +23,28 @@ from .models.phemex import PhemexDataStore
 from .typedefs import WsJsonHandler, WsStrHandler
 
 __all__: Tuple[str, ...] = (
-    'Client',
-    'request',
-    'get',
-    'post',
-    'put',
-    'delete',
-    'BybitDataStore',
-    'CoincheckDataStore',
-    'BybitInverseDataStore',
-    'BybitUSDTDataStore',
-    'FTXDataStore',
-    'BinanceDataStore',
-    'bitbankDataStore',
-    'bitFlyerDataStore',
-    'BitgetDataStore',
-    'BitMEXDataStore',
-    'GMOCoinDataStore',
-    'OKXDataStore',
-    'PhemexDataStore',
-    'experimental',
-    'print',
-    'print_handler',
+    "Client",
+    "request",
+    "get",
+    "post",
+    "put",
+    "delete",
+    "BybitDataStore",
+    "CoincheckDataStore",
+    "BybitInverseDataStore",
+    "BybitUSDTDataStore",
+    "FTXDataStore",
+    "BinanceDataStore",
+    "bitbankDataStore",
+    "bitFlyerDataStore",
+    "BitgetDataStore",
+    "BitMEXDataStore",
+    "GMOCoinDataStore",
+    "OKXDataStore",
+    "PhemexDataStore",
+    "experimental",
+    "print",
+    "print_handler",
 )
 
 
